## 港股通每日成交统计

接口：ggt_daily

描述：获取港股通每日成交信息，数据从2014年开始

限量：单次最大1000，总量数据不限制

积分：用户积2000积分可调取，5000积分以上频次相对较高，请自行提高积分，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期 （格式YYYYMMDD，下同。支持单日和多日输入） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期 |
| buy_amount | float | Y | 买入成交金额（亿元） |
| buy_volume | float | Y | 买入成交笔数（万笔） |
| sell_amount | float | Y | 卖出成交金额（亿元） |
| sell_volume | float | Y | 卖出成交笔数（万笔） |

接口示例

```python
pro = ts.pro_api()

#获取单日全部统计
df = pro.ggt_daily(trade_date='20190625')

#获取多日统计信息
df = pro.ggt_daily(trade_date='20190925,20180924,20170925')

#获取时间段统计信息
df = pro.ggt_daily(start_date='20180925', end_date='20190925)
```

数据示例

```python
trade_date  buy_amount  buy_volume  sell_amount  sell_volume
0     20190925       31.22        5.54        27.07         4.55
```